@@ -1,21 +1,22 @@
 package Log::Contextual::Easy::Default;
-$Log::Contextual::Easy::Default::VERSION = '0.008001';
-# ABSTRACT: Import all logging methods with WarnLogger as default
-
 use strict;
 use warnings;
 
-use base 'Log::Contextual';
+our $VERSION = '0.009000';
+
+use Log::Contextual ();
+BEGIN { our @ISA = qw(Log::Contextual) }
 
 sub arg_default_logger {
-   if ($_[1]) {
-      return $_[1];
-   } else {
-      require Log::Contextual::WarnLogger;
-      my $package = uc(caller(3));
-      $package =~ s/::/_/g;
-      return Log::Contextual::WarnLogger->new({env_prefix => $package});
-   }
+  if ($_[1]) {
+    return $_[1];
+  }
+  else {
+    require Log::Contextual::WarnLogger;
+    my $package = uc $_[2];
+    $package =~ s/::/_/g;
+    return Log::Contextual::WarnLogger->new({env_prefix => $package});
+  }
 }
 
 sub default_import { qw(:dlog :log ) }
@@ -28,13 +29,15 @@ __END__
 
 =encoding UTF-8
 
+=for :stopwords Arthur Axel "fREW" Schmidt
+
 =head1 NAME
 
 Log::Contextual::Easy::Default - Import all logging methods with WarnLogger as default
 
 =head1 VERSION
 
-version 0.008001
+version 0.009000
 
 =head1 SYNOPSIS
 
@@ -61,10 +64,10 @@ By default, this module enables a L<Log::Contextual::WarnLogger>
 with C<env_prefix> based on the module's name that uses
 Log::Contextual::Easy. The logging levels are set to C<trace> C<debug>,
 C<info>, C<warn>, C<error>, and C<fatal> (in this order) and all
-logging functions (L<log_...|Log::Contextual/"log_$level">,
-L<logS_...|Log::Contextual/"logS_$level">,
-L<Dlog_...|Log::Contextual/"Dlog_$level">, and
-L<Dlog...|Log::Contextual/"DlogS_$level">) are exported.
+logging functions (L<< C<log_...>|Log::Contextual/"log_$level" >>,
+L<< C<logS_...>|Log::Contextual/"logS_$level" >>,
+L<< C<Dlog_...>|Log::Contextual/"Dlog_$level" >>, and
+L<< C<Dlog...>|Log::Contextual/"DlogS_$level" >>) are exported.
 
 For what C<::Default> implies, see L<Log::Contextual/-default_logger>.
 
@@ -76,13 +79,22 @@ For what C<::Default> implies, see L<Log::Contextual/-default_logger>.
 
 =back
 
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website
+L<https://github.com/haarg/Log-Contextual/issues>
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
 =head1 AUTHOR
 
 Arthur Axel "fREW" Schmidt <frioux+cpan@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2018 by Arthur Axel "fREW" Schmidt.
+This software is copyright (c) 2024 by Arthur Axel "fREW" Schmidt.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
